@@ -14,7 +14,12 @@ def test_json():
     sock = mocket.Mocket(response_headers)
     pool.socket.return_value = sock
     sent = []
-    sock.send.side_effect = sent.append
+
+    def _send(data):
+        sent.append(data)
+        return len(data)
+
+    sock.send.side_effect = _send
 
     s = adafruit_requests.Session(pool)
     headers = {"user-agent": "blinka/1.0.0"}
